//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: DOMParserWrapper.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//
package siena.xml;

import org.apache.xerces.parsers.DOMParser;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
import org.xml.sax.InputSource;
import org.xml.sax.ErrorHandler;

/**
 * This class is used to wrap the ugly details of parsing a XML document from the users. It handles any type of error conditions while parsing the xml document and deals with them accordenly. This may mean throwing an exception or returning with a null return value. Upon finishing parsing it will return a W3C Document that contains the DOM.
 * @author Chris Corliss
 * @version 0.1
 * @see org.xml.sax.ErrorHandler
 * @since 11-05-2001 
 */

public class DOMParserWrapper implements ErrorHandler {
    /**
     * This is the actual parser which this class is wrapping.
     * @since 11-05-2001
     * @see org.apache.xerces.parsers.DOMParser*/
    private DOMParser parser;

    /**
     * This is the constructor for the parser.
     *
     *@since 11-20-01
     */
    
    public DOMParserWrapper() {
        parser = new DOMParser();
    }
    
    /**
     * This method parses the XML passed in as the string and returns
     * the DOM Document.
     * @param xmlString The string containing the XML
     * @since 11-05-2001
     * @return W3C DOM Document for the XML
     * @see org.apache.xerces.parsers.DOMParser 
     */

    public Document parse(String xmlString) {
        InputSource source = new InputSource(new java.io.StringReader(xmlString));
        try {
	        parse(source);
        } catch (Exception e) {
            //XXX - This is not what we should do for error handling!
            e.printStackTrace();
        }
        return parser.getDocument();
    }

    /**
     * This method will parse the given XML document that is in the InputSource
     * wrapper.
     *
     * @param inputSource InputSource object that contains the XML document.
     * @return W3C Document for the DOM.
     * @exception SAXException Thrown when the XML string parsed contains a syntax error.
     */

    public Document parse(InputSource inputSource) throws SAXException {
        try {
            parser.parse(inputSource);     
        } catch (java.io.IOException exception) {
            throw new SAXException(exception.toString());
        }
        return parser.getDocument();
    }

    public void error(SAXParseException exception) throws SAXException {
    }

    public void warning(SAXParseException exception) throws SAXException {
    }

    public void fatalError(SAXParseException exception) throws SAXException {
    }

}
