//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: XMLProcessorTest.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//

/*
 * XMLProcessorTest.java
 * JUnit based test
 *
 * Created on December 2, 2001, 9:21 PM
 */                

package siena.xml.tests;

import junit.framework.*;
import java.util.HashMap;
import java.util.Vector;
import java.io.FileInputStream;
import org.xml.sax.InputSource;
import org.w3c.dom.Node;
import org.w3c.dom.Attr;
import org.w3c.dom.NodeList;
import org.w3c.dom.NamedNodeMap;
import siena.xml.rules.Rule;
import siena.xml.rules.RulesGenerator;

/**
 *
 * @author unknown
 */                                
public class XMLProcessorTest extends TestCase {
    
    private static final String xmlNotification = 
        "<testNotification><data>NOTIFICATION</data>"+
        "<list><item index=\"0\"><name>test item one</name>"+
        "<value>110.00</value></item><item index=\"2\">"+
        "<name>test item two</name><value>1.0</value></item></list>"+
        "</testNotification>";
 
    private siena.xml.XMLProcessor processor = null;

    public XMLProcessorTest(java.lang.String testName) {
        super(testName);
    }        
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(XMLProcessorTest.class);
        return suite;
    }
    
    protected void setUp() throws Exception {
        super.setUp();
        processor = new siena.xml.XMLProcessor();
    }

    /** Test of setStyleSheet method, of class siena.xml.XMLProcessor. */
    public void testSetStyleSheet() {
        java.io.StringWriter writer = null;
        java.io.PrintWriter printWriter = null;
        
        System.out.println(" - Test: XMLProcessor - setStyleSheet method");
        
        try {
            processor.setStyleSheet(this.getClass().getResource("test.xsd").getFile());
        } catch (siena.SienaException exception) {
            writer = new java.io.StringWriter();
            printWriter = new java.io.PrintWriter(writer);
            writer.write("Exception caught during test run: ");
            writer.write("\n\n*******BEGIN EXCEPTION********\n\n");
            exception.printStackTrace(printWriter);
            writer.write("\n*******END EXCEPTION********\n");
            fail(writer.toString());
        }
            
    }
    
    /** Test of translate method, of class siena.xml.XMLProcessor. */
    public void testTranslate() {
        siena.Notification notification = null;
        java.io.StringWriter writer = null;
        java.io.PrintWriter printWriter = null;

        System.out.println(" - Test: XMLProcessor - translate method");

        try {
            processor.setStyleSheet(this.getClass().getResource("test.xsd").getFile());
            notification = processor.translate(xmlNotification);            
        } catch (siena.SienaException exception) {
            writer = new java.io.StringWriter();
            printWriter = new java.io.PrintWriter(writer);
            writer.write("Exception caught during test run: ");
            writer.write("\n\n*******BEGIN EXCEPTION********\n\n");
            exception.printStackTrace(printWriter);
            writer.write("\n*******END EXCEPTION********\n");
            fail(writer.toString());
        }

        Assert.assertNotNull("Expecting attribute data but was not in the notification.", notification.getAttribute("data"));
        Assert.assertNotNull("Expecting attribute item$quant but was not in the notification.", notification.getAttribute("item$quant"));
        Assert.assertNotNull("Expecting attribute value$max but was not in the notification.", notification.getAttribute("value$max"));
        Assert.assertNotNull("Expecting attribute value$min but was not in the notification.", notification.getAttribute("value$min"));
        Assert.assertNotNull("Expecting attribute item/0/name but was not in the notification.", notification.getAttribute("item/0/name"));
        Assert.assertNotNull("Expecting attribute item/0/value but was not in the notification.", notification.getAttribute("item/0/value"));
        Assert.assertNotNull("Expecting attribute item/2/name but was not in the notification.", notification.getAttribute("item/2/name"));
        Assert.assertNotNull("Expecting attribute item/2/value but was not in the notification.", notification.getAttribute("item/2/value"));
        Assert.assertNotNull("Expecting attribute index.min but was not in the notification.", notification.getAttribute("index$min"));
        Assert.assertNotNull("Expecting attribute index.max but was not in the notification.", notification.getAttribute("index$max"));

    }
    
    /** Test of setUserRules method, of class siena.xml.XMLProcessor. */
    public void testSetUserRules() {
        siena.Notification notification = null;
        java.io.StringWriter writer = null;
        java.io.PrintWriter printWriter = null;

        System.out.println(" - Test: XMLProcessor - setUserRules method");
        
        try {
            processor.setUserRules(this.getClass().getResource("user.rules").getFile());
            notification = processor.translate(xmlNotification);
        } catch (Exception exception) {
            writer = new java.io.StringWriter();
            printWriter = new java.io.PrintWriter(writer);
            writer.write("Exception caught during test run: ");
            writer.write("\n\n*******BEGIN EXCEPTION********\n\n");
            exception.printStackTrace(printWriter);
            writer.write("\n*******END EXCEPTION********\n");
            fail(writer.toString());            
        }

        Assert.assertNotNull("Expecting attribute index/test item one/name but was not in the notification.", notification.getAttribute("item/test item one/name"));
        Assert.assertNull("Not Expecting attribute index/test item two/value but was in the notification.", notification.getAttribute("item/test item two/value"));
        Assert.assertNotNull("Expecting attribute testGroup but was not in the notification.", notification.getAttribute("testGroup"));
    }
    
    /** Test of clearUserRules method, of class siena.xml.XMLProcessor. */
    public void testClearUserRules() {
        java.io.StringWriter writer = null;
        java.io.PrintWriter printWriter = null;
        siena.Notification notification = null;
        
        System.out.println(" - Test: XMLProcessor - clearUserRules method");        
        
        System.out.println("Calling the test to set the user rules to make sure it is working...");
        testSetUserRules();
        processor.clearUserRules();
        System.out.println("Calling the test for the translate method to see if the user rules were cleared...");
        testTranslate();
    }
    
}
