//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: ComparisonPredicate.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//
/*
 * ComparisonPredicate.java
 *
 * Created on November 26, 2001, 1:22 AM
 */

package siena.xml.xpath;

/** Object that represents a predicate that is a comparison of two values.
 *
 * @author Chris Corliss
 * @version 0.1
 */
public class ComparisonPredicate extends Predicate {

    private String op = null;
    
    private int intArg = 0;
    
    private double doubleArg = 0;
    
    private String stringArg = null;
    
    private boolean isArgIntegerValue = false;
    
    /** Creates new ComparisonPredicate */
    public ComparisonPredicate(String data) {
        super(Predicate.COMPARE);
        int signIndex = -1;
        int startOfOp = -1;
        String arg1 = null;
        String arg2 = null;

        signIndex = data.indexOf("<");
        if (signIndex == -1) {
            signIndex = data.indexOf(">");
        }

        startOfOp = signIndex;
        if (data.charAt(signIndex+1) == '=') {
            signIndex++;
        } else if (data.charAt(signIndex-1) == '=') {
            startOfOp--;
        }
        
        this.op = data.substring(startOfOp, signIndex+1);
        
        arg1 = data.substring(0,startOfOp).trim();
        arg2 = data.substring(signIndex+1).trim();
        
        if (setIntegerArg(arg1) || setDoubleArg(arg1)) {
            stringArg = arg2;
        } else if (setIntegerArg(arg2) || setDoubleArg(arg2)) {
            stringArg = arg1;
        }               
    }

    private boolean setIntegerArg(String data) {
        try {
            intArg = Integer.parseInt(data);
        } catch (Exception e) {
            return false;
        }
        isArgIntegerValue = true;        
        return true;
    }
    
    private boolean setDoubleArg(String data) {
        try {
            doubleArg = Double.parseDouble(data);
        } catch (Exception e) {
            return false;
        }
        isArgIntegerValue = false;        
        return true;
    }
    
    public String getStringArg() {
        return stringArg;
    }
    
    public int getIntegerArg() {
        return intArg;
    }
    
    public double getDoubleArg() {
        return doubleArg;
    }
    
    public String getOp() {
        return op;
    }
    
    public boolean isThereAnIntegerArg() {
        return isArgIntegerValue;
    }
}
