//
//  This file is part of SienaXML, an XML interface to the 
//  Siena wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Chris Corliss <corliss@falcon.stortek.com>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2001-2002 University of Colorado
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//  
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: FunctionPredicate.java,v 1.1.1.1 2002/06/07 22:42:37 jgiacomo Exp $
//
/* Generated by Together */

package siena.xml.xpath;

import java.util.StringTokenizer;

/** Object that represents a function call that is in a predicate.
 */
public class FunctionPredicate extends Predicate {
    
    private boolean[] isArgsQuoted = null;
    private boolean isStringFunction = false;
    private String function;
    private String[] stringArgs = null;
    private static final java.util.HashSet stringFunctions = new java.util.HashSet();
    
    {
        stringFunctions.add("substring");
        stringFunctions.add("starts-with");
        stringFunctions.add("contains");
        stringFunctions.add("substring-before");
        stringFunctions.add("substring-after");
        stringFunctions.add("string-length");
        stringFunctions.add("concat");
    }
    
    
    public FunctionPredicate(String functionName) {
        super(Predicate.FUNCTION);
        
        int indexOfParen = 0;
        StringTokenizer tokens = new StringTokenizer(functionName,",");
        String token = null;
        String currentArg = null;
        int numArgs = 0;
        
        indexOfParen = functionName.indexOf('(');
        function = functionName.substring(0,indexOfParen);
        numArgs = tokens.countTokens();
        stringArgs = new String[numArgs];
        isArgsQuoted = new boolean[numArgs];
        
        if (stringFunctions.contains(function)) {
            this.isStringFunction = true;
            for (int i = 0; i < numArgs; i++) {
                token = tokens.nextToken().trim();

                // Check for parenths. If the exist, get rid of them.
                  
                indexOfParen = token.indexOf('(');
                if (indexOfParen != -1) {
                    currentArg = token.substring(indexOfParen+1,token.length());
                } else {            
                    indexOfParen = token.indexOf(')');
                    if (indexOfParen != -1) {
                        currentArg = token.substring(0,indexOfParen);
                    } else {
                        currentArg = token;
                    }
                }
            
                // Check to see if this arguement is a quoted string.
                if (currentArg.charAt(0) == '\"') {
                    currentArg = currentArg.replace('\"',' ').trim();
                    isArgsQuoted[i] = true;
                }
            
                stringArgs[i] = new String(currentArg);

            }
        }
    }
    
    public boolean isPredicateStringFunction() {
        return isStringFunction;
    }
    
    public String getStringArgAt(int index) {
        return stringArgs[index];
    }
    
    public boolean isArgAQuotedString(int index) {
        return isArgsQuoted[index];
    }
    
    public String getFunctionName() {
        return function;
    }    
    
    public int getNumberOfArgs() {
        return stringArgs.length;
    }
}
